@@ -8,10 +8,13 @@ import jsii
 import jsii.compat
 import publication
 
+import aws_cdk.aws_ec2
+import aws_cdk.aws_iam
+import aws_cdk.aws_kms
 import aws_cdk.core
 import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-fsx", "1.36.1", __name__[0:-6], "aws-fsx@1.36.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-fsx", "1.37.0", __name__[0:-6], "aws-fsx@1.37.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
